EXPORTS
	??0CActiveTestState@@QAE@H@Z @ 1 NONAME ; CActiveTestState::CActiveTestState(int)
	??0CBaseCommandParser@@IAE@XZ @ 2 NONAME ; CBaseCommandParser::CBaseCommandParser(void)
	??0CBaseSectionParser@@IAE@AAVCTestScript@@@Z @ 3 NONAME ; CBaseSectionParser::CBaseSectionParser(class CTestScript &)
	??0CBaseTestHarness@@IAE@AAVRTest@@@Z @ 4 NONAME ; CBaseTestHarness::CBaseTestHarness(class RTest &)
	??0CCheckAttachment@@QAE@HHAAVCMsvEntrySelection@@AAVCMsvTestUtils@@@Z @ 5 NONAME ; CCheckAttachment::CCheckAttachment(int, int, class CMsvEntrySelection &, class CMsvTestUtils &)
	??0CCheckMessageFolder@@QAE@ABVTDesC16@@AAVCMsvTestUtils@@@Z @ 6 NONAME ; CCheckMessageFolder::CCheckMessageFolder(class TDesC16 const &, class CMsvTestUtils &)
	??0CCheckNewFlag@@QAE@HHAAVCMsvEntrySelection@@AAVCMsvTestUtils@@@Z @ 7 NONAME ; CCheckNewFlag::CCheckNewFlag(int, int, class CMsvEntrySelection &, class CMsvTestUtils &)
	??0CCheckPriority@@QAE@HHAAVCMsvEntrySelection@@AAVCMsvTestUtils@@@Z @ 8 NONAME ; CCheckPriority::CCheckPriority(int, int, class CMsvEntrySelection &, class CMsvTestUtils &)
	??0CCheckRemoteFolderSize@@QAE@HAAVCMsvTestUtils@@@Z @ 9 NONAME ; CCheckRemoteFolderSize::CCheckRemoteFolderSize(int, class CMsvTestUtils &)
	??0CCheckSelectionCount@@QAE@HAAVCMsvEntrySelection@@AAVCMsvTestUtils@@@Z @ 10 NONAME ; CCheckSelectionCount::CCheckSelectionCount(int, class CMsvEntrySelection &, class CMsvTestUtils &)
	??0CCleanMessageFolder@@QAE@AAVCMsvTestUtils@@@Z @ 11 NONAME ; CCleanMessageFolder::CCleanMessageFolder(class CMsvTestUtils &)
	??0CCopySelection@@QAE@AAVCMsvClientTest@@@Z @ 12 NONAME ; CCopySelection::CCopySelection(class CMsvClientTest &)
	??0CDeleteSelection@@QAE@AAVCMsvClientTest@@@Z @ 13 NONAME ; CDeleteSelection::CDeleteSelection(class CMsvClientTest &)
	??0CDumpMessageStore@@QAE@AAVCMsvTestUtils@@@Z @ 14 NONAME ; CDumpMessageStore::CDumpMessageStore(class CMsvTestUtils &)
	??0CGoClientSide@@QAE@AAVCMsvTestUtils@@@Z @ 15 NONAME ; CGoClientSide::CGoClientSide(class CMsvTestUtils &)
	??0CGoServerSide@@QAE@AAVCMsvTestUtils@@@Z @ 16 NONAME ; CGoServerSide::CGoServerSide(class CMsvTestUtils &)
	??0CLongWait@@QAE@H@Z @ 17 NONAME ; CLongWait::CLongWait(int)
	??0CLongWait@@QAE@XZ @ 18 NONAME ; CLongWait::CLongWait(void)
	??0CMainSectionParser@@IAE@AAVCMainTestHarness@@AAVCTestScript@@@Z @ 19 NONAME ; CMainSectionParser::CMainSectionParser(class CMainTestHarness &, class CTestScript &)
	??0CMainTestHarness@@IAE@AAVRTest@@@Z @ 20 NONAME ; CMainTestHarness::CMainTestHarness(class RTest &)
	??0CMoveSelection@@QAE@AAVCMsvClientTest@@@Z @ 21 NONAME ; CMoveSelection::CMoveSelection(class CMsvClientTest &)
	??0CMsvClientTest@@IAE@AAVCMsvTestUtils@@AAVRTest@@@Z @ 22 NONAME ; CMsvClientTest::CMsvClientTest(class CMsvTestUtils &, class RTest &)
	??0CMsvClientTest@@IAE@PAVCMsvTestUtils@@AAVRTest@@@Z @ 23 NONAME ; CMsvClientTest::CMsvClientTest(class CMsvTestUtils *, class RTest &)
	??0CMsvTestEntry@@QAE@AAVCMsvClientTest@@@Z @ 24 NONAME ; CMsvTestEntry::CMsvTestEntry(class CMsvClientTest &)
	??0CMsvTestEntrySectionParser@@IAE@AAVCTestScript@@AAVCMsvTestEntry@@@Z @ 25 NONAME ; CMsvTestEntrySectionParser::CMsvTestEntrySectionParser(class CTestScript &, class CMsvTestEntry &)
	??0CResetMessageServer@@QAE@AAVCMsvClientTest@@@Z @ 26 NONAME ; CResetMessageServer::CResetMessageServer(class CMsvClientTest &)
	??0CSelectAllMessages@@QAE@AAJAAVCMsvEntrySelection@@AAVCMsvTestUtils@@@Z @ 27 NONAME ; CSelectAllMessages::CSelectAllMessages(long &, class CMsvEntrySelection &, class CMsvTestUtils &)
	??0CSelectEntryById@@QAE@JAAJAAVCMsvTestUtils@@@Z @ 28 NONAME ; CSelectEntryById::CSelectEntryById(long, long &, class CMsvTestUtils &)
	??0CSelectFirstInSelection@@QAE@HAAVCMsvEntrySelection@@AAVCMsvTestUtils@@@Z @ 29 NONAME ; CSelectFirstInSelection::CSelectFirstInSelection(int, class CMsvEntrySelection &, class CMsvTestUtils &)
	??0CSelectLastInSelection@@QAE@HAAVCMsvEntrySelection@@AAVCMsvTestUtils@@@Z @ 30 NONAME ; CSelectLastInSelection::CSelectLastInSelection(int, class CMsvEntrySelection &, class CMsvTestUtils &)
	??0CSelectPopulatedInSelection@@QAE@AAVCMsvEntrySelection@@AAVCMsvTestUtils@@@Z @ 31 NONAME ; CSelectPopulatedInSelection::CSelectPopulatedInSelection(class CMsvEntrySelection &, class CMsvTestUtils &)
	??0TTestDebugInfo@@QAE@AAVCTestScript@@HH@Z @ 32 NONAME ; TTestDebugInfo::TTestDebugInfo(class CTestScript &, int, int)
	??0TTestDebugInfo@@QAE@AAVCTestScript@@HHH@Z @ 33 NONAME ; TTestDebugInfo::TTestDebugInfo(class CTestScript &, int, int, int)
	??0TTestDebugInfo@@QAE@XZ @ 34 NONAME ; TTestDebugInfo::TTestDebugInfo(void)
	??1CAddComment@@UAE@XZ @ 35 NONAME ; CAddComment::~CAddComment(void)
	??1CBaseCommandParser@@UAE@XZ @ 36 NONAME ; CBaseCommandParser::~CBaseCommandParser(void)
	??1CBaseSectionParser@@UAE@XZ @ 37 NONAME ; CBaseSectionParser::~CBaseSectionParser(void)
	??1CBaseTestHarness@@UAE@XZ @ 38 NONAME ; CBaseTestHarness::~CBaseTestHarness(void)
	??1CCheckBodyText@@UAE@XZ @ 39 NONAME ; CCheckBodyText::~CCheckBodyText(void)
	??1CCopySelection@@UAE@XZ @ 40 NONAME ; CCopySelection::~CCopySelection(void)
	??1CDeleteSelection@@UAE@XZ @ 41 NONAME ; CDeleteSelection::~CDeleteSelection(void)
	??1CLongWait@@UAE@XZ @ 42 NONAME ; CLongWait::~CLongWait(void)
	??1CMoveSelection@@UAE@XZ @ 43 NONAME ; CMoveSelection::~CMoveSelection(void)
	??1CMsvClientTest@@UAE@XZ @ 44 NONAME ; CMsvClientTest::~CMsvClientTest(void)
	??1CMsvTestEntrySectionParser@@UAE@XZ @ 45 NONAME ; CMsvTestEntrySectionParser::~CMsvTestEntrySectionParser(void)
	??1CSelectEntry@@UAE@XZ @ 46 NONAME ; CSelectEntry::~CSelectEntry(void)
	??1CTestScript@@UAE@XZ @ 47 NONAME ; CTestScript::~CTestScript(void)
	??1CTestSection@@UAE@XZ @ 48 NONAME ; CTestSection::~CTestSection(void)
	??1MBaseTestState@@UAE@XZ @ 49 NONAME ; MBaseTestState::~MBaseTestState(void)
	?AddCommandL@CBaseCommandParser@@IAEXABVTDesC16@@@Z @ 50 NONAME ; void CBaseCommandParser::AddCommandL(class TDesC16 const &)
	?AddCommandL@CTestSection@@QAEXABV?$TBuf8@$0IA@@@HH@Z @ 51 NONAME ; void CTestSection::AddCommandL(class TBuf8<128> const &, int, int)
	?AddCommandParserL@CBaseSectionParser@@IAEXPAVCBaseCommandParser@@@Z @ 52 NONAME ; void CBaseSectionParser::AddCommandParserL(class CBaseCommandParser *)
	?AddStateL@CBaseTestHarness@@UAEXPAVMBaseTestState@@VTTestDebugInfo@@@Z @ 53 NONAME ; void CBaseTestHarness::AddStateL(class MBaseTestState *, class TTestDebugInfo)
	?CanParse@CBaseCommandParser@@QBEHABVTDesC16@@@Z @ 54 NONAME ; int CBaseCommandParser::CanParse(class TDesC16 const &) const
	?CheckNumberOfArgumentsL@CBaseCommandParser@@IAEXH@Z @ 55 NONAME ; void CBaseCommandParser::CheckNumberOfArgumentsL(int)
	?CommandNameLC@TTestDebugInfo@@IAEPAVHBufC16@@XZ @ 56 NONAME ; class HBufC16 * TTestDebugInfo::CommandNameLC(void)
	?ConstructL@CBaseCommandParser@@MAEXXZ @ 57 NONAME ; void CBaseCommandParser::ConstructL(void)
	?ConstructL@CBaseSectionParser@@MAEXABVTDesC16@@@Z @ 58 NONAME ; void CBaseSectionParser::ConstructL(class TDesC16 const &)
	?ConstructL@CBaseTestHarness@@MAEXXZ @ 59 NONAME ; void CBaseTestHarness::ConstructL(void)
	?ConstructL@CMainSectionParser@@IAEXXZ @ 60 NONAME ; void CMainSectionParser::ConstructL(void)
	?ConstructL@CMainTestHarness@@MAEXXZ @ 61 NONAME ; void CMainTestHarness::ConstructL(void)
	?ConstructL@CMsvClientTest@@MAEXXZ @ 62 NONAME ; void CMsvClientTest::ConstructL(void)
	?ConstructL@CMsvTestEntrySectionParser@@MAEXABVTDesC16@@@Z @ 63 NONAME ; void CMsvTestEntrySectionParser::ConstructL(class TDesC16 const &)
	?CurrentCommandPosition@CTestSection@@QBEHXZ @ 64 NONAME ; int CTestSection::CurrentCommandPosition(void) const
	?CurrentOperation@CMsvClientTest@@QAEAAVCMsvOperation@@XZ @ 65 NONAME ; class CMsvOperation & CMsvClientTest::CurrentOperation(void)
	?DoCancel@CBaseTestHarness@@UAEXXZ @ 66 NONAME ; void CBaseTestHarness::DoCancel(void)
	?DoCancel@CCopySelection@@UAEXXZ @ 67 NONAME ; void CCopySelection::DoCancel(void)
	?DoCancel@CDeleteSelection@@UAEXXZ @ 68 NONAME ; void CDeleteSelection::DoCancel(void)
	?DoCancel@CLongWait@@UAEXXZ @ 69 NONAME ; void CLongWait::DoCancel(void)
	?DoCancel@CMoveSelection@@UAEXXZ @ 70 NONAME ; void CMoveSelection::DoCancel(void)
	?DoCancel@CMsvClientTest@@UAEXXZ @ 71 NONAME ; void CMsvClientTest::DoCancel(void)
	?Error@CBaseCommandParser@@QAEAAVTDesC16@@XZ @ 72 NONAME ; class TDesC16 & CBaseCommandParser::Error(void)
	?GetCurrentCommand@CTestSection@@QBEHAAVTDes16@@@Z @ 73 NONAME ; int CTestSection::GetCurrentCommand(class TDes16 &) const
	?GetDebugInfo@MBaseTestState@@QBEABVTTestDebugInfo@@XZ @ 74 NONAME ; class TTestDebugInfo const & MBaseTestState::GetDebugInfo(void) const
	?GetLineL@CTestScript@@QAEHAAV?$TBuf8@$0IA@@@H@Z @ 75 NONAME ; int CTestScript::GetLineL(class TBuf8<128> &, int)
	?GetSectionL@CTestScript@@QAEPAVCTestSection@@ABVTDesC16@@@Z @ 76 NONAME ; class CTestSection * CTestScript::GetSectionL(class TDesC16 const &)
	?LineNumber@TTestDebugInfo@@QAEHXZ @ 77 NONAME ; int TTestDebugInfo::LineNumber(void)
	?LoadFileL@CTestScript@@QAEHABVTDesC16@@@Z @ 78 NONAME ; int CTestScript::LoadFileL(class TDesC16 const &)
	?LogCommentL@CBaseTestHarness@@UAEXABVTDesC16@@@Z @ 79 NONAME ; void CBaseTestHarness::LogCommentL(class TDesC16 const &)
	?LogCommentL@CMainSectionParser@@MAEXABVTDesC16@@@Z @ 80 NONAME ; void CMainSectionParser::LogCommentL(class TDesC16 const &)
	?LogCommentL@CMsvTestEntrySectionParser@@UAEXABVTDesC16@@@Z @ 81 NONAME ; void CMsvTestEntrySectionParser::LogCommentL(class TDesC16 const &)
	?MsvTestUtils@CMsvClientTest@@QAEAAVCMsvTestUtils@@XZ @ 82 NONAME ; class CMsvTestUtils & CMsvClientTest::MsvTestUtils(void)
	?NewL@CAddComment@@SAPAV1@ABVCDesC16ArrayFlat@@AAVCMsvTestUtils@@@Z @ 83 NONAME ; class CAddComment * CAddComment::NewL(class CDesC16ArrayFlat const &, class CMsvTestUtils &)
	?NewL@CCheckBodyText@@SAPAV1@HAAVTDesC16@@AAVCMsvEntrySelection@@AAVCMsvTestUtils@@@Z @ 84 NONAME ; class CCheckBodyText * CCheckBodyText::NewL(int, class TDesC16 &, class CMsvEntrySelection &, class CMsvTestUtils &)
	?NewL@CMainSectionParser@@SAPAV1@AAVCMainTestHarness@@AAVCTestScript@@@Z @ 85 NONAME ; class CMainSectionParser * CMainSectionParser::NewL(class CMainTestHarness &, class CTestScript &)
	?NewL@CMainTestHarness@@SAPAV1@AAVRTest@@@Z @ 86 NONAME ; class CMainTestHarness * CMainTestHarness::NewL(class RTest &)
	?NewL@CMsvClientTest@@SAPAV1@AAVCMsvTestUtils@@AAVRTest@@@Z @ 87 NONAME ; class CMsvClientTest * CMsvClientTest::NewL(class CMsvTestUtils &, class RTest &)
	?NewL@CMsvClientTest@@SAPAV1@PAVCMsvTestUtils@@AAVRTest@@@Z @ 88 NONAME ; class CMsvClientTest * CMsvClientTest::NewL(class CMsvTestUtils *, class RTest &)
	?NewL@CMsvOperationParser@@SAPAV1@AAVCMsvClientTest@@@Z @ 89 NONAME ; class CMsvOperationParser * CMsvOperationParser::NewL(class CMsvClientTest &)
	?NewL@CMsvSelectParser@@SAPAV1@AAVCMsvClientTest@@@Z @ 90 NONAME ; class CMsvSelectParser * CMsvSelectParser::NewL(class CMsvClientTest &)
	?NewL@CMsvTestEntryCommandParser@@SAPAV1@AAVCMsvTestEntry@@@Z @ 91 NONAME ; class CMsvTestEntryCommandParser * CMsvTestEntryCommandParser::NewL(class CMsvTestEntry &)
	?NewL@CMsvTestEntrySectionParser@@SAPAV1@ABVTDesC16@@AAVCTestScript@@AAVCMsvTestEntry@@@Z @ 92 NONAME ; class CMsvTestEntrySectionParser * CMsvTestEntrySectionParser::NewL(class TDesC16 const &, class CTestScript &, class CMsvTestEntry &)
	?NewL@CMsvUtilitiesParser@@SAPAV1@AAVCMsvClientTest@@@Z @ 93 NONAME ; class CMsvUtilitiesParser * CMsvUtilitiesParser::NewL(class CMsvClientTest &)
	?NewL@CSelectEntry@@SAPAV1@ABVTDesC16@@ABJPAJAAVCMsvTestUtils@@@Z @ 94 NONAME ; class CSelectEntry * CSelectEntry::NewL(class TDesC16 const &, long const &, long *, class CMsvTestUtils &)
	?NewL@CSelectEntry@@SAPAV1@ABVTDesC16@@ABJPAVCMsvEntrySelection@@AAVCMsvTestUtils@@@Z @ 95 NONAME ; class CSelectEntry * CSelectEntry::NewL(class TDesC16 const &, long const &, class CMsvEntrySelection *, class CMsvTestUtils &)
	?NewL@CTestScript@@SAPAV1@AAVRFs@@@Z @ 96 NONAME ; class CTestScript * CTestScript::NewL(class RFs &)
	?NewL@CTestSection@@SAPAV1@HABVTDesC16@@H@Z @ 97 NONAME ; class CTestSection * CTestSection::NewL(int, class TDesC16 const &, int)
	?NextCommand@CTestSection@@QAEHXZ @ 98 NONAME ; int CTestSection::NextCommand(void)
	?ParseL@CBaseCommandParser@@QAEXABVTDesC16@@VTTestDebugInfo@@@Z @ 99 NONAME ; void CBaseCommandParser::ParseL(class TDesC16 const &, class TTestDebugInfo)
	?ParseL@CBaseSectionParser@@QAEXXZ @ 100 NONAME ; void CBaseSectionParser::ParseL(void)
	?ProcessL@CMsvOperationParser@@UAEXXZ @ 101 NONAME ; void CMsvOperationParser::ProcessL(void)
	?ProcessL@CMsvSelectParser@@UAEXXZ @ 102 NONAME ; void CMsvSelectParser::ProcessL(void)
	?ProcessL@CMsvTestEntryCommandParser@@UAEXXZ @ 103 NONAME ; void CMsvTestEntryCommandParser::ProcessL(void)
	?ProcessL@CMsvUtilitiesParser@@UAEXXZ @ 104 NONAME ; void CMsvUtilitiesParser::ProcessL(void)
	?Reset@CMsvClientTest@@UAEXXZ @ 105 NONAME ; void CMsvClientTest::Reset(void)
	?RunError@CActiveTestState@@UAEHH@Z @ 106 NONAME ; int CActiveTestState::RunError(int)
	?RunError@CBaseTestHarness@@UAEHH@Z @ 107 NONAME ; int CBaseTestHarness::RunError(int)
	?RunL@CBaseTestHarness@@UAEXXZ @ 108 NONAME ; void CBaseTestHarness::RunL(void)
	?RunL@CCopySelection@@UAEXXZ @ 109 NONAME ; void CCopySelection::RunL(void)
	?RunL@CDeleteSelection@@UAEXXZ @ 110 NONAME ; void CDeleteSelection::RunL(void)
	?RunL@CLongWait@@UAEXXZ @ 111 NONAME ; void CLongWait::RunL(void)
	?RunL@CMoveSelection@@UAEXXZ @ 112 NONAME ; void CMoveSelection::RunL(void)
	?SectionName@CTestSection@@QBEABVTDesC16@@XZ @ 113 NONAME ; class TDesC16 const & CTestSection::SectionName(void) const
	?SectionNameLC@TTestDebugInfo@@IAEPAVHBufC16@@XZ @ 114 NONAME ; class HBufC16 * TTestDebugInfo::SectionNameLC(void)
	?SectionPosition@CTestSection@@QBEHXZ @ 115 NONAME ; int CTestSection::SectionPosition(void) const
	?SetCurrentOperation@CMsvClientTest@@QAEXPAVCMsvOperation@@@Z @ 116 NONAME ; void CMsvClientTest::SetCurrentOperation(class CMsvOperation *)
	?SetDebugInfo@MBaseTestState@@QAEXABVTTestDebugInfo@@@Z @ 117 NONAME ; void MBaseTestState::SetDebugInfo(class TTestDebugInfo const &)
	?SetErrorL@CBaseCommandParser@@IAEXABVTDesC16@@@Z @ 118 NONAME ; void CBaseCommandParser::SetErrorL(class TDesC16 const &)
	?SetHeapFailureTesting@CBaseTestHarness@@UAEXH@Z @ 119 NONAME ; void CBaseTestHarness::SetHeapFailureTesting(int)
	?SetTestHarnessName@TTestDebugInfo@@QAEXH@Z @ 120 NONAME ; void TTestDebugInfo::SetTestHarnessName(int)
	?StartL@CAddComment@@UAEXAAVTRequestStatus@@@Z @ 121 NONAME ; void CAddComment::StartL(class TRequestStatus &)
	?StartL@CBaseTestHarness@@UAEXAAVTRequestStatus@@@Z @ 122 NONAME ; void CBaseTestHarness::StartL(class TRequestStatus &)
	?StartL@CCheckAttachment@@UAEXAAVTRequestStatus@@@Z @ 123 NONAME ; void CCheckAttachment::StartL(class TRequestStatus &)
	?StartL@CCheckBodyText@@UAEXAAVTRequestStatus@@@Z @ 124 NONAME ; void CCheckBodyText::StartL(class TRequestStatus &)
	?StartL@CCheckMessageFolder@@UAEXAAVTRequestStatus@@@Z @ 125 NONAME ; void CCheckMessageFolder::StartL(class TRequestStatus &)
	?StartL@CCheckNewFlag@@UAEXAAVTRequestStatus@@@Z @ 126 NONAME ; void CCheckNewFlag::StartL(class TRequestStatus &)
	?StartL@CCheckPriority@@UAEXAAVTRequestStatus@@@Z @ 127 NONAME ; void CCheckPriority::StartL(class TRequestStatus &)
	?StartL@CCheckRemoteFolderSize@@UAEXAAVTRequestStatus@@@Z @ 128 NONAME ; void CCheckRemoteFolderSize::StartL(class TRequestStatus &)
	?StartL@CCheckSelectionCount@@UAEXAAVTRequestStatus@@@Z @ 129 NONAME ; void CCheckSelectionCount::StartL(class TRequestStatus &)
	?StartL@CCleanMessageFolder@@UAEXAAVTRequestStatus@@@Z @ 130 NONAME ; void CCleanMessageFolder::StartL(class TRequestStatus &)
	?StartL@CCopySelection@@UAEXAAVTRequestStatus@@@Z @ 131 NONAME ; void CCopySelection::StartL(class TRequestStatus &)
	?StartL@CDeleteSelection@@UAEXAAVTRequestStatus@@@Z @ 132 NONAME ; void CDeleteSelection::StartL(class TRequestStatus &)
	?StartL@CDumpMessageStore@@UAEXAAVTRequestStatus@@@Z @ 133 NONAME ; void CDumpMessageStore::StartL(class TRequestStatus &)
	?StartL@CGoClientSide@@UAEXAAVTRequestStatus@@@Z @ 134 NONAME ; void CGoClientSide::StartL(class TRequestStatus &)
	?StartL@CGoServerSide@@UAEXAAVTRequestStatus@@@Z @ 135 NONAME ; void CGoServerSide::StartL(class TRequestStatus &)
	?StartL@CLongWait@@UAEXAAVTRequestStatus@@@Z @ 136 NONAME ; void CLongWait::StartL(class TRequestStatus &)
	?StartL@CMainTestHarness@@UAEXAAVTRequestStatus@@@Z @ 137 NONAME ; void CMainTestHarness::StartL(class TRequestStatus &)
	?StartL@CMoveSelection@@UAEXAAVTRequestStatus@@@Z @ 138 NONAME ; void CMoveSelection::StartL(class TRequestStatus &)
	?StartL@CMsvTestEntry@@UAEXAAVTRequestStatus@@@Z @ 139 NONAME ; void CMsvTestEntry::StartL(class TRequestStatus &)
	?StartL@CResetMessageServer@@UAEXAAVTRequestStatus@@@Z @ 140 NONAME ; void CResetMessageServer::StartL(class TRequestStatus &)
	?StartL@CSelectAllMessages@@UAEXAAVTRequestStatus@@@Z @ 141 NONAME ; void CSelectAllMessages::StartL(class TRequestStatus &)
	?StartL@CSelectEntry@@UAEXAAVTRequestStatus@@@Z @ 142 NONAME ; void CSelectEntry::StartL(class TRequestStatus &)
	?StartL@CSelectEntryById@@UAEXAAVTRequestStatus@@@Z @ 143 NONAME ; void CSelectEntryById::StartL(class TRequestStatus &)
	?StartL@CSelectFirstInSelection@@UAEXAAVTRequestStatus@@@Z @ 144 NONAME ; void CSelectFirstInSelection::StartL(class TRequestStatus &)
	?StartL@CSelectLastInSelection@@UAEXAAVTRequestStatus@@@Z @ 145 NONAME ; void CSelectLastInSelection::StartL(class TRequestStatus &)
	?StartL@CSelectPopulatedInSelection@@UAEXAAVTRequestStatus@@@Z @ 146 NONAME ; void CSelectPopulatedInSelection::StartL(class TRequestStatus &)
	?TestComplete@CMsvTestEntry@@QAEXH@Z @ 147 NONAME ; void CMsvTestEntry::TestComplete(int)
	?TestCompleteStringLC@TTestDebugInfo@@QAEPAVHBufC16@@XZ @ 148 NONAME ; class HBufC16 * TTestDebugInfo::TestCompleteStringLC(void)
	?TestConsole@CBaseTestHarness@@QAEAAVRTest@@XZ @ 149 NONAME ; class RTest & CBaseTestHarness::TestConsole(void)
	?TestFailedStringL@TTestDebugInfo@@QAEPAVHBufC16@@H@Z @ 150 NONAME ; class HBufC16 * TTestDebugInfo::TestFailedStringL(int)
	?TestHarnessNameLC@TTestDebugInfo@@IAEPAVHBufC16@@XZ @ 151 NONAME ; class HBufC16 * TTestDebugInfo::TestHarnessNameLC(void)
	?TestStartStringLC@TTestDebugInfo@@QAEPAVHBufC16@@XZ @ 152 NONAME ; class HBufC16 * TTestDebugInfo::TestStartStringLC(void)
	?TestVisible@CMsvTestEntry@@QAEXH@Z @ 153 NONAME ; void CMsvTestEntry::TestVisible(int)

